@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11984 2020-03-19 12:21:32Z Lavender $
+# $Id: models.py 11988 2020-03-20 07:52:23Z Andy $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,15 +11,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2020-03-19 21:21:32 +0900 (週四, 19 三月 2020) $
-# $Revision: 11984 $
+# $Author: Andy $
+# $Date: 2020-03-20 15:52:23 +0800 (週五, 20 三月 2020) $
+# $Revision: 11988 $
 
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 
 class URL(models.Model):
-    url = models.CharField(max_length=400, editable=False, db_index=True, unique=True)
+    url = models.TextField(editable=False, db_index=True, unique=True)
     viewCount = models.PositiveIntegerField(
         verbose_name=_("View count"), default=0)
     likeCount = models.PositiveIntegerField(
